# Instructions
1. Install the LVREML-Python package using:
<code> pip install -i https://test.pypi.org/simple/ LVREML</code>
2. Run the notebook named <code> LVREML_tutorial.ipynb </code> to run the analysis on yeast data.
